summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorVencislav Atanasov <user890104@freemyipod.org>2024-11-20 02:22:53 +0200
committerSolomon Peachy <pizza@shaftnet.org>2024-11-20 10:58:32 -0500
commitf040c4c9ec30b9269ebff89b2aff65d1d0a435d6 (patch)
treebaf7b55b367127ba157a48466186db5e57456170
parent64d94889a2a118626902ce69143f9815f4b78b91 (diff)
downloadrockbox-f040c4c9ec.tar.gz
rockbox-f040c4c9ec.zip
Rename CPU_S5L870X to CPU_S5L87XX
This is a preparation to introduce support for the following SoC models: S5L8720 (iPod Nano 4G, iPod Touch 2G), S5L8730 (iPod Nano 5G), S5L8723 (iPod Nano 6G) and S5L8740 (iPod Nano 7G) The whole family consists of SoCs which are similar, running ARMv6 and Thumb2 instructions, but some peripherals are located at a different address. No functional change is to be expected so far. Change-Id: If1f7669c49cf110ccc52c5234cc42ffd6f2b4e80
-rw-r--r--apps/debug_menu.c2
-rw-r--r--apps/plugins/mpegplayer/audio_thread.c2
-rw-r--r--apps/settings.h4
-rw-r--r--firmware/SOURCES2
-rw-r--r--firmware/export/config.h8
-rw-r--r--lib/rbcodec/codecs/demac/libdemac/demac_config.h4
-rw-r--r--lib/rbcodec/codecs/libatrac/atrac3.h4
-rw-r--r--lib/rbcodec/codecs/libmusepack/synth_filter_arm.S4
-rw-r--r--lib/rbcodec/codecs/libtremor/config-tremor.h4
-rw-r--r--lib/rbcodec/codecs/libwma/wmadec.h4
10 files changed, 19 insertions, 19 deletions
diff --git a/apps/debug_menu.c b/apps/debug_menu.c
index 39d9a2a4e2..2691abbc01 100644
--- a/apps/debug_menu.c
+++ b/apps/debug_menu.c
@@ -2767,7 +2767,7 @@ static const struct {
#endif
#if defined(CPU_COLDFIRE) || defined(CPU_PP) \
|| CONFIG_CPU == S3C2440 || CONFIG_CPU == IMX31L || CONFIG_CPU == AS3525 \
- || CONFIG_CPU == DM320 || defined(CPU_S5L870X) || CONFIG_CPU == AS3525v2 \
+ || CONFIG_CPU == DM320 || defined(CPU_S5L87XX) || CONFIG_CPU == AS3525v2 \
|| CONFIG_CPU == RK27XX || CONFIG_CPU == JZ4760B
{ "View I/O ports", dbg_ports },
#endif
diff --git a/apps/plugins/mpegplayer/audio_thread.c b/apps/plugins/mpegplayer/audio_thread.c
index 764ad111f2..6f39425630 100644
--- a/apps/plugins/mpegplayer/audio_thread.c
+++ b/apps/plugins/mpegplayer/audio_thread.c
@@ -59,7 +59,7 @@ static unsigned char mad_main_data[MAD_BUFFER_MDLEN];
is for Coldfire. */
/* 4608 bytes */
-#if defined(CPU_COLDFIRE) || defined(CPU_S5L870X)
+#if defined(CPU_COLDFIRE) || defined(CPU_S5L87XX)
static mad_fixed_t mad_frame_overlap[2][32][18] IBSS_ATTR;
#else
static mad_fixed_t mad_frame_overlap[2][32][18];
diff --git a/apps/settings.h b/apps/settings.h
index c6ba14573b..b04152d508 100644
--- a/apps/settings.h
+++ b/apps/settings.h
@@ -218,8 +218,8 @@ enum { ALARM_START_WPS = 0,
This helps to save space for menus and options. */
#define VIRT_SIZE 0xFFFF /* more than enough for our string ID range */
-#if defined(CPU_S5L870X)
-/* the S5L870X has IRAM at 0, so we use 0xffff bytes right after that */
+#if defined(CPU_S5L87XX)
+/* the S5L87XX has IRAM at 0, so we use 0xffff bytes right after that */
#define VIRT_PTR ((unsigned char*)0x40000)
#elif CONFIG_CPU==DM320
/* the DM320 has IRAM at 0, so we use 0xffff bytes right after that */
diff --git a/firmware/SOURCES b/firmware/SOURCES
index 192cdb711d..47b4c56ca8 100644
--- a/firmware/SOURCES
+++ b/firmware/SOURCES
@@ -596,7 +596,7 @@ target/arm/bits-armv4.S
# if CONFIG_CPU == IMX233 || CONFIG_CPU == DM320 \
|| CONFIG_CPU == AS3525 || CONFIG_CPU == AS3525v2 \
|| CONFIG_CPU == S3C2440 || CONFIG_CPU == TCC7801 \
- || defined(CPU_S5L870X)
+ || defined(CPU_S5L87XX)
target/arm/mmu-arm.S
# endif
# endif
diff --git a/lib/rbcodec/codecs/demac/libdemac/demac_config.h b/lib/rbcodec/codecs/demac/libdemac/demac_config.h
index fa4f008036..8ff4719923 100644
--- a/lib/rbcodec/codecs/demac/libdemac/demac_config.h
+++ b/lib/rbcodec/codecs/demac/libdemac/demac_config.h
@@ -44,11 +44,11 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110, USA
#define FILTER_BITS 32
#endif
-#if !defined(CPU_PP) && !defined(CPU_S5L870X)
+#if !defined(CPU_PP) && !defined(CPU_S5L87XX)
#define FILTER256_IRAM
#endif
-#if CONFIG_CPU == PP5002 || defined(CPU_S5L870X)
+#if CONFIG_CPU == PP5002 || defined(CPU_S5L87XX)
/* Code and data IRAM for speed (PP5002 has a broken cache), not enough IRAM
* for the insane filter buffer. Reciprocal table for division in IRAM. */
#define ICODE_SECTION_DEMAC_ARM .icode
diff --git a/lib/rbcodec/codecs/libatrac/atrac3.h b/lib/rbcodec/codecs/libatrac/atrac3.h
index 912924cf6c..e73d8f2045 100644
--- a/lib/rbcodec/codecs/libatrac/atrac3.h
+++ b/lib/rbcodec/codecs/libatrac/atrac3.h
@@ -24,8 +24,8 @@
#include "codeclib.h"
#if (CONFIG_CPU == PP5022) || (CONFIG_CPU == PP5024) || \
- (CONFIG_CPU == MCF5250) || defined(CPU_S5L870X)
-/* PP5022/24, MCF5250 and S5L870x have larger IRAM */
+ (CONFIG_CPU == MCF5250) || defined(CPU_S5L87XX)
+/* PP5022/24, MCF5250 and S5L87xx have larger IRAM */
#define IBSS_ATTR_LARGE_IRAM IBSS_ATTR
#define ICODE_ATTR_LARGE_IRAM ICODE_ATTR
#define ICONST_ATTR_LARGE_IRAM ICONST_ATTR
diff --git a/lib/rbcodec/codecs/libmusepack/synth_filter_arm.S b/lib/rbcodec/codecs/libmusepack/synth_filter_arm.S
index 9bd4e04626..23bc429c49 100644
--- a/lib/rbcodec/codecs/libmusepack/synth_filter_arm.S
+++ b/lib/rbcodec/codecs/libmusepack/synth_filter_arm.S
@@ -21,8 +21,8 @@
#include "config.h"
-#if defined(CPU_S5L870X)
- /* Moving this asm routine to iram is (little) faster on S5L870x. */
+#if defined(CPU_S5L87XX)
+ /* Moving this asm routine to iram is (little) faster on S5L87xx. */
.section .icode, "ax", %progbits
#else
.section .text, "ax", %progbits
diff --git a/lib/rbcodec/codecs/libtremor/config-tremor.h b/lib/rbcodec/codecs/libtremor/config-tremor.h
index cf2dbe977d..125276bd57 100644
--- a/lib/rbcodec/codecs/libtremor/config-tremor.h
+++ b/lib/rbcodec/codecs/libtremor/config-tremor.h
@@ -31,8 +31,8 @@
#ifdef USE_IRAM
#define TREMOR_USE_IRAM
-/* Define CPU of large IRAM (PP5022/5024, MCF5250) */
-#if (CONFIG_CPU == PP5022) || (CONFIG_CPU == PP5024) || defined(CPU_S5L870X) || (CONFIG_CPU == MCF5250)
+/* Define CPU of large IRAM (PP5022/5024, S5L87XX, MCF5250) */
+#if (CONFIG_CPU == PP5022) || (CONFIG_CPU == PP5024) || defined(CPU_S5L87XX) || (CONFIG_CPU == MCF5250)
/* PCM_BUFFER : 32768 byte (4096*2*4 or 2048*4*4) *
* WINDOW_LOOKUP : 9216 Byte (256*4 + 2048*4) *
* TOTAL : 41984 */
diff --git a/lib/rbcodec/codecs/libwma/wmadec.h b/lib/rbcodec/codecs/libwma/wmadec.h
index b3bca4f452..0fc24a01e8 100644
--- a/lib/rbcodec/codecs/libwma/wmadec.h
+++ b/lib/rbcodec/codecs/libwma/wmadec.h
@@ -59,8 +59,8 @@
#define IBSS_ATTR_WMA_XL_IRAM
#define ICONST_ATTR_WMA_XL_IRAM
-#elif (CONFIG_CPU == S5L8700) || (CONFIG_CPU == S5L8701)
-/* S5L870x has even more IRAM. Use it. */
+#elif defined(CPU_S5L87XX)
+/* S5L87xx has even more IRAM. Use it. */
#define IBSS_ATTR_WMA_LARGE_IRAM IBSS_ATTR
#define IBSS_ATTR_WMA_XL_IRAM IBSS_ATTR
#define ICONST_ATTR_WMA_XL_IRAM ICONST_ATTR
diff --git a/firmware/export/config.h b/firmware/export/config.h
index c53f8d5c69..d6195aef26 100644
--- a/firmware/export/config.h
+++ b/firmware/export/config.h
@@ -666,9 +666,9 @@ Lyre prototype 1 */
#define CPU_PP502x
#endif
-/* define for all cpus from S5L870X family */
+/* define for all cpus from S5L87XX family */
#if (CONFIG_CPU == S5L8700) || (CONFIG_CPU == S5L8701) || (CONFIG_CPU == S5L8702)
-#define CPU_S5L870X
+#define CPU_S5L87XX
#endif
/* define for all cpus from TCC780 family */
@@ -1029,7 +1029,7 @@ Lyre prototype 1 */
#if defined(HAVE_USBSTACK) || (CONFIG_CPU == JZ4732) || (CONFIG_CPU == JZ4760B) \
|| (CONFIG_CPU == AS3525) || (CONFIG_CPU == AS3525v2) \
- || defined(CPU_S5L870X) || (CONFIG_CPU == S3C2440) \
+ || defined(CPU_S5L87XX) || (CONFIG_CPU == S3C2440) \
|| defined(APPLICATION) || (CONFIG_CPU == PP5002) \
|| (CONFIG_CPU == RK27XX) || (CONFIG_CPU == IMX233) || \
(defined(HAVE_LCD_COLOR) && (LCD_STRIDEFORMAT == HORIZONTAL_STRIDE))
@@ -1118,7 +1118,7 @@ Lyre prototype 1 */
(CONFIG_CPU == PNX0101) || \
(CONFIG_CPU == TCC7801) || \
(CONFIG_CPU == IMX233 && !defined(PLUGIN) && !defined(CODEC)) || /* IMX233: core only */ \
- defined(CPU_S5L870X)) || /* Samsung S5L8700: core, plugins, codecs */ \
+ defined(CPU_S5L87XX)) || /* Samsung S5L87XX: core, plugins, codecs */ \
((CONFIG_CPU == JZ4732 || CONFIG_CPU == JZ4760B) && !defined(PLUGIN) && !defined(CODEC)) /* Jz47XX: core only */
#define ICODE_ATTR __attribute__ ((section(".icode")))
#define ICONST_ATTR __attribute__ ((section(".irodata")))